pub struct OptionalCheckIgnoreConfig {
pub details: Option<bool>,
}Expand description
Optional configuration for checking ignored files, used for partial updates.
Fields
details: Option<bool>Optional setting for whether to show detailed information when checking ignored files.