pub struct OptionalCoreConfig {
pub xvc_repo_version: Option<u8>,
pub verbosity: Option<String>,
pub guid: Option<String>,
}Expand description
Optional core configuration for Xvc, used for partial updates.
Fields
xvc_repo_version: Option<u8>Optional Xvc repository version.
verbosity: Option<String>Optional verbosity level for logging.
guid: Option<String>Optional GUID for the repository. This is a legacy field and should be migrated to .xvc/guid file.