pub struct OptionalGitConfig {
pub use_git: Option<bool>,
pub command: Option<String>,
pub auto_commit: Option<bool>,
pub auto_stage: Option<bool>,
}Expand description
Optional Git integration configuration for Xvc, used for partial updates.
Fields
use_git: Option<bool>Optional setting for whether to use Git for version control.
command: Option<String>Optional Git command to execute.
auto_commit: Option<bool>Optional setting for whether to automatically commit changes.
auto_stage: Option<bool>Optional setting for whether to automatically stage changes.