pub struct XvcLoadParams {
pub current_dir: AbsolutePath,
pub xvc_root_dir: Option<AbsolutePath>,
pub include_system_config: bool,
pub include_user_config: bool,
pub include_project_config: bool,
pub include_local_config: bool,
pub project_config_path: Option<AbsolutePath>,
pub local_config_path: Option<AbsolutePath>,
pub include_environment_config: bool,
pub command_line_config: Option<Vec<String>>,
}Expand description
How should we initialize the configuration?
It’s possible to ignore certain sources by supplying None to their values here.
Fields
current_dir: AbsolutePathThe directory where the application runs. This can be set by various Options. It affects how paths are handled in general.
xvc_root_dir: Option<AbsolutePath>This is Some(dir) if we run in an Xvc directory Guid will be read from here in version 2 onwards
include_system_config: boolShould we include system configuration?
If true, it’s read from [SYSTEM_CONFIG_DIRS].
include_user_config: boolShould the user’s (home) config be included.
If true, it’s read from [USER_CONFIG_DIRS].
include_project_config: boolShould we include the project config at .xvc/config.toml?
include_local_config: boolShould we include the local config at .xvc/config-local.toml
project_config_path: Option<AbsolutePath>Where should we load the project’s (public) configuration? It’s loaded in [XvcRootInner::new]
local_config_path: Option<AbsolutePath>Where should we load the project’s (private) configuration? It’s loaded in [XvcRootInner::new] TODO: Add a option to ignore this
include_environment_config: boolShould we include configuration from the environment.
If true, look for all variables in the form
XVC_group.key=value
from the environment and put them into the configuration.
command_line_config: Option<Vec<String>>Command line configuration
Implementations
Sourceimpl XvcLoadParams
impl XvcLoadParams
Sourcepub fn new(
current_dir: AbsolutePath,
xvc_root_dir: Option<AbsolutePath>,
) -> XvcLoadParams
pub fn new( current_dir: AbsolutePath, xvc_root_dir: Option<AbsolutePath>, ) -> XvcLoadParams
Create a new blank config params
Sourcepub fn include_system_config(self, include_system_config: bool) -> XvcLoadParams
pub fn include_system_config(self, include_system_config: bool) -> XvcLoadParams
Update include_system_config value
Sourcepub fn include_user_config(self, include_user_config: bool) -> XvcLoadParams
pub fn include_user_config(self, include_user_config: bool) -> XvcLoadParams
Update include_user_config value
Sourcepub fn project_config_path(
self,
project_config_path: Option<AbsolutePath>,
) -> XvcLoadParams
pub fn project_config_path( self, project_config_path: Option<AbsolutePath>, ) -> XvcLoadParams
Update project config path
Sourcepub fn local_config_path(
self,
local_config_path: Option<AbsolutePath>,
) -> XvcLoadParams
pub fn local_config_path( self, local_config_path: Option<AbsolutePath>, ) -> XvcLoadParams
Update local config path
Sourcepub fn include_environment_config(
self,
include_environment_config: bool,
) -> XvcLoadParams
pub fn include_environment_config( self, include_environment_config: bool, ) -> XvcLoadParams
Whether to include enviroment variables in the configuration
Sourcepub fn command_line_config(
self,
command_line_config: Option<Vec<String>>,
) -> XvcLoadParams
pub fn command_line_config( self, command_line_config: Option<Vec<String>>, ) -> XvcLoadParams
Command line config from key=value definitions