Git operations for Xvc repositories
Functions
- build_
gitignore - Returns xvc_walker::IgnoreRules for
.gitignoreIt’s used to check whether a path is already ignored by Git. - exec_
git - Run a git command with a specific git binary
- get_
absolute_ git_ command - Find the absolute path to the git executable to run TODO: This must be cached. It makes a which request every time a command runs
- get_
git_ tracked_ files - Get files tracked by git
- git_
auto_ commit - Commit
.xvcdirectory after Xvc operations - git_
auto_ stage - runs
git add .xvc *.gitignore *.xvcignoreto stage the files after Xvc operations - git_
checkout_ ref - Checkout a git branch or tag before running an Xvc command
- git_
ignored - Run
git check-ignoreto check if a path is ignored by Git - gix_
list_ branches - List local branches in a Git repository
- gix_
list_ references - Return all tags and branches from a repository using Gix
- handle_
git_ automation - This receives
xvc_rootownership because as a final operation, it must drop the root to record the last entity counter before commit. - inside_
git - Check whether a path is inside a Git repository.
It returns
Noneif not, otherwise returns the closest directory with.git. It works by checking.gitdirectories in parents, until no more parent left. - stash_
user_ staged_ files - Stash user’s staged files to avoid committing them before auto-commit
- unstash_
user_ staged_ files - Unstash user’s staged files after auto-commit