pub fn inside_git(path: &Path) -> Option<PathBuf>Expand description
Check whether a path is inside a Git repository.
It returns None if not, otherwise returns the closest directory with .git.
It works by checking .git directories in parents, until no more parent left.