pub struct XvcConfig {
pub current_dir: AbsolutePath,
/* private fields */
}Expand description
Keeps track of all Xvc configuration.
It’s created by [XvcRoot] using the options from [XvcConfigInitParams]. Keeps the current directory, that can also be set manually from the command line. It loads several config maps (one for each XvcConfigOptionSource) and cascadingly merges them to get an actual configuration.
Fields
current_dir: AbsolutePathCurrent directory. It can be set with xvc -C option
Implementations
Sourceimpl XvcConfig
impl XvcConfig
Sourcepub fn new_v2(config_init_params: &XvcLoadParams) -> Result<XvcConfig, Error>
pub fn new_v2(config_init_params: &XvcLoadParams) -> Result<XvcConfig, Error>
Loads the default configuration from p.
The configuration must be a valid TOML document.
Sourcepub fn config(&self) -> &XvcConfiguration
pub fn config(&self) -> &XvcConfiguration
Return the current configuration
Sourcepub fn system_config_file() -> Result<PathBuf, Error>
pub fn system_config_file() -> Result<PathBuf, Error>
Return the system configuration file path for Xvc FIXME: Return Absolute Path
Sourcepub fn user_config_file() -> Result<PathBuf, Error>
pub fn user_config_file() -> Result<PathBuf, Error>
Return the user configuration file path for Xvc
Sourcepub fn load_optional_config_from_file(
path: &Path,
) -> Result<XvcOptionalConfiguration, Error>
pub fn load_optional_config_from_file( path: &Path, ) -> Result<XvcOptionalConfiguration, Error>
Load an XvcOptionalConfiguration from a file or returns a blank config if the file is not found
Sourcepub fn load_command_line_config(
cli_opt_vector: &Option<Vec<String>>,
) -> Result<XvcOptionalConfiguration, Error>
pub fn load_command_line_config( cli_opt_vector: &Option<Vec<String>>, ) -> Result<XvcOptionalConfiguration, Error>
Loads configuration from command line arguments. Parses a vector of key-value strings into an XvcOptionalConfiguration.
Sourcepub fn current_dir(&self) -> Result<&AbsolutePath, Error>
pub fn current_dir(&self) -> Result<&AbsolutePath, Error>
Where do we run the command?
This can be modified by options in the command line, so it’s not always equal to std::env::current_dir()
Sourcepub fn verbosity(&self) -> XvcVerbosity
pub fn verbosity(&self) -> XvcVerbosity
The current verbosity level.
Set with core.verbosity option.
Sourcepub fn find_value_source(&self, key: &str) -> Option<XvcConfigOptionSource>
pub fn find_value_source(&self, key: &str) -> Option<XvcConfigOptionSource>
Find where a configuration value is defined, by checking configuration layers from highest priority to lowest.