Module xvc_core::util::git

source ·
Git operations

Functions

Returns xvc_walker::IgnoreRules for .gitignore It’s used to check whether a path is already ignored by Git.
Check whether a path is inside a Git repository. It returns None if not, otherwise returns the closest directory with .git. It works by checking .git directories in parents, until no more parent left.